@@ -5,6 +5,7 @@ from pettingzoo.utils import agent_selector
 import numpy as np
 import pygame
 from pettingzoo.utils import wrappers
+from gym.utils import EzPickle
 
 
 def env(**kwargs):
@@ -16,12 +17,12 @@ def env(**kwargs):
     return env
 
 
-class raw_env(AECEnv):
+class raw_env(AECEnv, EzPickle):
 
     metadata = {'render.modes': ['human']}
 
     def __init__(self, seed=None, *args, **kwargs):
-        super().__init__()
+        EzPickle.__init__(self, seed, *args, **kwargs)
         self.env = _env(*args, seed, **kwargs)
         pygame.init()
         self.num_agents = self.env.num_agents
@@ -76,5 +77,5 @@ class raw_env(AECEnv):
             return self.observe(self.agent_selection)
 
     def observe(self, agent):
-        o = np.array(self.env.safely_observe(self.agent_name_mapping[agent]), np.float32)
-        return o
+        o = self.env.safely_observe(self.agent_name_mapping[agent])
+        return np.swapaxes(o, 2, 0)
